@@ -2,7 +2,7 @@ package DateTime::Format::Flexible;
 use strict;
 use warnings;
 
-our $VERSION = '0.32';
+our $VERSION = '0.37';
 
 use base 'DateTime::Format::Builder';
 
@@ -100,6 +100,7 @@ my $formats =
 [
  [ preprocess => \&_fix_alpha ] ,
  { length => [18..22] , params => $YMDHMSAP , regex => qr{\A(\d{4})$DELIM(\d{2})$DELIM(\d{2})\s$HMS\s?$AMPM\z} , postprocess => \&_fix_ampm } ,
+ { length => [16..20] , params => $YMDHMAP , regex => qr{\A(\d{4})$DELIM(\d{2})$DELIM(\d{2})\s$HM\s?$AMPM\z} , postprocess => \&_fix_ampm } ,
 
  # 2011-06-16-17.43.30.000000
  { length => [26] , params => $YMDHMSNS , regex => qr{\A(\d{4})$DELIM(\d{2})$DELIM(\d{2})${DELIM}$HMSNS\z} } ,
@@ -520,7 +521,7 @@ sub _fix_alpha
     my $stripped = $date;
     $stripped =~ s{$DELIM|$HMSDELIM}{}gm;
 
-    if ( $stripped =~ m{(\D)} )
+    if ( $stripped =~ m{(\D)} or exists $p->{time_zone})
     {
         printf( "# before lang: %s\n", $date ) if $ENV{DFF_DEBUG};
         ( $date , $p ) = $lang->_cleanup( $date , $p );
@@ -606,7 +607,7 @@ sub _parse_timezone
         }
         if ( DateTime::TimeZone->is_valid_name( $tz ) )
         {
-            printf( "#  timezone matched\n" ) if $ENV{DFF_DEBUG};
+            printf( "#  timezone matched ($tz)\n" ) if $ENV{DFF_DEBUG};
             $date =~ s{\Q$orig_tz\E}{};
             $p->{time_zone} = $tz;
             return ( $date , $p );
